@@ -55,23 +55,23 @@ class EvalMetric:
             input = self.tokenize_text(input.strip())
         if isinstance(input, list):
             for i, t in enumerate(input):
-                input[i] = self.tokenize_text(t)
+                input[i] = self.tokenize_text(t.strip())
 
         if isinstance(predicted, str):
             predicted = self.tokenize_text(predicted)
         if isinstance(predicted, list):
             for i, t in enumerate(predicted):
-                predicted[i] = self.tokenize_text(t)
+                predicted[i] = self.tokenize_text(t.strip())
 
         if isinstance(target, str):
             targets = []
-            if "[SEP]" in target:
-                targets.extend([self.tokenize_text(st.strip()) for st in target.split("[SEP]")])
+            if self.tokenizer.sep_token in target:
+                targets.extend([self.tokenize_text(st.strip()) for st in target.split(self.tokenizer.sep_token)])
             else:
                 targets.append(self.tokenize_text(target.strip()))
         if isinstance(target, list):
             for i, t in enumerate(target):
-                target[i] = self.tokenize_text(t)
+                target[i] = self.tokenize_text(t.strip())
             targets = target
 
         if self.max_candidate - len(targets) > 0 and "nlg" in task:
@@ -107,7 +107,7 @@ class EvalMetric:
                             f1_score = 1
                         else:
                             em_score = 0
-                            f1_score = _f1_score(predict, target)
+                            f1_score = _f1_score(str(predict), str(target))
                         em_list.append(em_score)
                         f1_list.append(f1_score)
                     em += max(em_list)
@@ -154,6 +154,7 @@ class EvalMetric:
                                      precision_recall_fscore_support(mlb.transform([t]), mlb.transform([p]),
                                                                      average='weighted')))
                     data_score.append([p, t, score])
+                print(mlb.classes_)
                 result = classification_report(
                     mlb.transform(targets),
                     mlb.transform(predicted),
